
************************************************************************************************************************************************************************************************
** Set directories
************************************************************************************************************************************************************************************************

* define the folder of the replication files as the stata directory *
* using the syntax in line 9 *

global Kresy_replication_directory "~/Dropbox/Poland/Replication_AER_final"

foreach path in  $Kresy_replication_directory  {
	capture cd "`path'"
	if _rc == 0 macro def path `path'
	}


************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
** Preparation steps:	
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************

** 0.1 Install additional ado files and create necessary directories
************************************************************************************************************************************************************************************************

	capture: ssc install estout
	capture: ssc install vcemway

	cap mkdir  "${path}/Results"
	cap mkdir  "${path}/Results/Tables/"
	cap mkdir  "${path}/Results/Figures/"
	cap mkdir  "${path}/Data/generated_data/"
	cap mkdir  "${path}/Data/generated_data/temp"

	
** 0.2 Build datasets that are the input to the analysis from the survey source files
************************************************************************************************************************************************************************************************

** Diagnoza
do "${path}/Original_source_data/Diagnoza/generating_diagnoza_2015_from_source.do"	

** Ancestry survey
do "${path}/Original_source_data/Ancestry/generating_cbos_with_1931_from_source.do"	
	
	
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
** REPLICATION STARTS HERE:	
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
************************************************************************************************************************************************************************************************
	
** 1. Prepare the main datasets for the analysis
************************************************************************************************************************************************************************************************

do "${path}/DoFiles/1.Build_datasets_for_analysis.do"

************************************************************************************************************************************************************************************************
** 2. Replicate results based on Diagnoza data 
************************************************************************************************************************************************************************************************

**    These include: 
**    Tables: 2, 5, 6, A1, A2, A3, A4, A10, A16, A19, A21, A22, A24
**	  Figures: 2, 3, 4, A8, A10, A11, A12, A15, A16

do "${path}/DoFiles/2.Regressions_Diagnoza.do"

************************************************************************************************************************************************************************************************
** 3. Replicate results based on CBOS data 
************************************************************************************************************************************************************************************************

**    These include: 
**    Tables: 3, 4, A8, A11, A12, A13, A14, A17, A24, A25, A26
**	  Figure: 5

do "${path}/DoFiles/3.Regressions_CBOS.do"

************************************************************************************************************************************************************************************************
** 4. Replicate results based on both DIAGNOZA and CBOS data combined
************************************************************************************************************************************************************************************************

**    Table: A18

do "${path}/DoFiles/4.Regressions_Diagnoza_AncestorSurvey.do"

************************************************************************************************************************************************************************************************
** 5. Replicate results comparing CBOS data with census data
************************************************************************************************************************************************************************************************

**    Figure: A9

do "${path}/DoFiles/5.Fig_App_DataQuality_CBOS.do"

************************************************************************************************************************************************************************************************
** 6. Replicate results based on LiTS Data
************************************************************************************************************************************************************************************************

**    These include: 
**    Tables: A9, A15, A20

do "${path}/DoFiles/6.Regressions_LiTS.do"

************************************************************************************************************************************************************************************************
** 8. Replicate Table A.23 
************************************************************************************************************************************************************************************************

do "${path}/DoFiles/7.Regressions_CBOS_community.do"

************************************************************************************************************************************************************************************************
** 8. To replicate Figure A.6 open "/Data/original_data/timing_of_arrival.xlsx"
************************************************************************************************************************************************************************************************

**    Figure: A6 -- plot of original data

