
         
set more off            
clear all               
* --------------------------------------------------


global dir_ANC "${path}/Original_source_data/Ancestry/source_ancestry_survey_files"

local dir="$dir_ANC"

clear
set more off

cd `dir'


* --------------------------------------------------
* use the original survey data

use Ancestry_survey_set_original.dta, clear


local anc_list "R F M FF MF FM MM FFF MFF FMF MMF FFM MFM FMM MMM A10_1 S10_1 S10_2 S10_3"
local anc_list1 "R F M FF MF FM MM FFF MFF FMF MMF FFM MFM FMM MMM A1_1 S1_1 S1_2 S1_3"
local anc_list2 "R F M FF MF FM MM FFF MFF FMF MMF FFM MFM FMM MMM"



********************************************************
**** generate demographic variables about respondents
********************************************************

gen age=  2016 - D2
label variable age "age"

**************

gen female=0
replace female=1 if D1==2
label variable female "the respondent is female"

cap label define female_label 0"male" 1"female"
label values female female_label

**************

gen working=.
replace working=1 if D3<4
replace working=0 if D3==4

gen pensioner=.
replace pensioner=1 if D5==12 | D5==13
replace pensioner=0 if D5<12 | (D5>13)&(D5!=.)

gen unemployed=.
replace unemployed=1 if D5==14
replace unemployed=0 if D5<14 | D5==15 |D5==16

gen student=.
replace student=1 if D5==11
replace student=0 if (D5<11)|(D5>11&D5!=.)

gen not_working=.
replace not_working=1 if D5==15 | D5==16
replace not_working=0 if D5<15

label variable working "the respondent is working D3=1|D3=2|D3=3"
label variable pensioner "the respondent is a pensioner D5=12|D5=13"
label variable unemployed "the respondent is unemployed D5=14"
label variable student "the respondent is a student D5=11"
label variable not_working "the respondent is not working D5==15|D5==16" 


cap label define yesno01 0"No" 1"Yes"

label values working yesno01
label values pensioner yesno01
label values unemployed yesno01
label values student yesno01
label values not_working yesno01


*******************

gen eduk4=.

replace eduk4=1 if D8==1 |D8==2
replace eduk4=2 if D8==3|D8==4
replace eduk4=3 if D8==5|D8==6| D8==7|D8==8
replace eduk4=4 if D8>8& D8!=.

label var eduk4 "education level"

label define eduk4k 1 "primary and less" 2 "basic professional and middle school" 3 "secondary" 4 "more than secondary" 
label values eduk4 eduk4k


*******************

gen primary_edu=.
replace primary_edu=1 if D8>1&D8!=.
replace primary_edu=0 if D8<2

gen secondary_edu=.
replace secondary_edu=1 if D8>5&D8!=.
replace secondary_edu=0 if D8<6
replace secondary_edu=0 if D8==7

gen higher_edu=.
replace higher_edu=1 if D8>=10&D8!=.
replace higher_edu=0 if D8<10

label variable primary_edu "respondent – at least primary education D8>=2"
label variable secondary_edu "respondent - at least secondary education D8=6|D8>=8"
label variable higher_edu "respondent – at least higher education D8>=10"

label values primary_edu yesno01
label values secondary_edu yesno01
label values higher_edu yesno01


*************************


gen rural=.
replace rural=1 if klasa_miejscowosci==1
replace rural=0 if (klasa_miejscowosci>1)& (klasa_miejscowosci!=.)

label variable rural "rural locality"

gen big_city=.
replace big_city=1 if klasa_miejscowosci==4
replace big_city=0 if klasa_miejscowosci<4

label variable big_city "big city locality"

gen roots_in_kresy=.
replace roots_in_kresy=1 if Z==1
replace roots_in_kresy=0 if (Z>1)& (Z!=.)

label variable roots_in_kresy "has roots in Kresy"

gen roots_in_central_poland=.
replace roots_in_central_poland=1 if Z==2
replace roots_in_central_poland=0 if (Z>2)&(Z!=.)|Z<2

label variable roots_in_central_poland "has roots in Central Poland"

gen roots_in_western_territories=.
replace roots_in_western_territories=1 if Z==3
replace roots_in_western_territories=0 if (Z>3)&(Z!=.)|Z<3

label variable roots_in_western_territories "has roots in Western territories"

gen roots_abroad=.
replace roots_abroad=1 if Z==4
replace roots_abroad=0 if Z<4

label variable roots_abroad "has roots abroad"

label values rural yesno01
label values big_city yesno01
label values roots_in_kresy yesno01
label values roots_in_central_poland yesno01
label values roots_in_western_territories yesno01
label values roots_abroad yesno01


***************************

gen married=.
replace married=1 if S0==2
replace married =0 if S0<2 | (S0>2 & S0!=.)

gen unmarried=.
replace unmarried=1 if S0==1
replace unmarried =0 if (S0>1) & (S0!=.)

gen divorced=.
replace divorced=1 if S0==3
replace divorced =0 if S0<3 |(S0>3 & S0!=.)

gen widow=.
replace widow=1 if S0==4
replace widow =0 if S0<4 |(S0>4 & S0!=.)

gen free_couple=.
replace free_couple=1 if S0==5
replace free_couple =0 if S0<5 


label variable married "respondent - married"
label variable unmarried "respondent - unmarried"
label variable divorced "respondent - divorced/separated"
label variable widow "respondent - widow"
label variable free_couple "respondent - free couple/civil partnership"


label values married yesno01
label values unmarried yesno01
label values divorced yesno01
label values widow yesno01
label values free_couple yesno01





**************************************************************************
* assign the same place to mothers when they lived together with fathers 
**************************************************************************

foreach var in pow_code1931_use latitude1939_use longitude1939_use data_quality_source origin_country_use rn woj_code pow_code_f_city{
replace M_`var'=F_`var' if P==1 
replace MF_`var'=FF_`var' if GP1==1 
replace MM_`var'=FM_`var' if GP2==1 
replace MFF_`var'=FFF_`var' if GGP1==1 
replace MMF_`var'=FMF_`var' if GGP2==1 
replace MFM_`var'=FFM_`var' if GGP3==1 
replace MMM_`var'=FMM_`var' if GGP4==1
}

foreach var in 1 2 3 4 5 6 7 8 9 10 11 12a 12{
replace M`var'=F`var' if P==1 
replace MF`var'=FF`var' if GP1==1 
replace MM`var'=FM`var' if GP2==1 
replace MFF`var'=FFF`var' if GGP1==1 
replace MMF`var'=FMF`var' if GGP2==1 
replace MFM`var'=FFM`var' if GGP3==1 
replace MMM`var'=FMM`var' if GGP4==1
}


rename A10_1_pow_code1931_use 		A1_1_pow_code1931_use 
rename A10_1_longitude1939_use 		A1_1_longitude1939_use 
rename A10_1_latitude1939_use 		A1_1_latitude1939_use 
rename A10_1_data_quality_source 	A1_1_data_quality_source 
rename S10_1_pow_code1931_use 		S1_1_pow_code1931_use 
rename S10_1_longitude1939_use 		S1_1_longitude1939_use 
rename S10_1_latitude1939_use 		S1_1_latitude1939_use 
rename S10_1_data_quality_source 	S1_1_data_quality_source 
rename S10_2_pow_code1931_use 		S1_2_pow_code1931_use 
rename S10_2_longitude1939_use 		S1_2_longitude1939_use 
rename S10_2_latitude1939_use 		S1_2_latitude1939_use 
rename S10_2_data_quality_source 	S1_2_data_quality_source  
rename S10_3_pow_code1931_use  		S1_3_pow_code1931_use 
rename S10_3_longitude1939_use  	S1_3_longitude1939_use 
rename S10_3_latitude1939_use 		S1_3_latitude1939_use 
rename S10_3_data_quality_source 	S1_3_data_quality_source 
rename A10_1_origin_country_use 	A1_1_origin_country_use
rename S10_1_origin_country_use 	S1_1_origin_country_use
rename S10_2_origin_country_use 	S1_2_origin_country_use
rename S10_3_origin_country_use 	S1_3_origin_country_use


quietly { 
********************************************************************************************************************************

********************************************************************************************************************************
*** add gminy_centeroid_coordinates
********************************************************************************************************************************

merge m:1 gminy_code using gminy_code_coordinates.dta

drop if _merge==2
drop _merge

label var latitude_gminy_cent "latitude of gminy centeroid"
label var longitude_gminy_cent "longitude of gminy centeroid"


********************************************************************************************************************************
*** ADD prussian data for current locations (gmina of respondent) for 1933, 1925, and 1900
********************************************************************************************************************************

**** merge in id for 1933 data for currect gmina of respondent 
merge m:1 gminy_code using gminy_code_map_id_dr_1933.dta
drop _merge

gen id=id_dr_1933
label var id_dr_1933 "map id for 1925 1933 germany"

merge m:1 id using  WeimarR_1925_1933_Census.dta
drop if _merge==2
drop _merge

gen LaborForcePart1925=TotalLabor1925/pop1925
drop TotalLabor1925
foreach var in protestant1925 catholic1925 jews1925 IndLabor1925 AgricLabor1925{
replace `var'=`var'/pop1925
}

gen LaborForcePart1933=TotalLabor1933/pop1933
drop TotalLabor1933
foreach var in Unemployed1933 AgricLabor1933 IndLabor1933{
replace `var'=`var'/pop1933
}

label var LaborForcePart1925  "Labor Force Participation 1925"
label var LaborForcePart1933  "Labor Force Participation 1933"

label var AgricLabor1925  "Agricultural Employment in 1925, % of population"
label var IndLabor1925    "Industrial and Trade Employment in 1925, % of population"
label var protestant1925  "Protestants in 1925, %"
label var catholic1925    "Catholics in 1925 %"
label var jews1925        "Jews in 1925, %"
label var Unemployed1933  "Unemployed in 1933, % of population"
label var AgricLabor1933  "Agricultural Employment in 1933,  % of population"
label var IndLabor1933    "Industrial Employment in 1933 % of population"


*** merge in id for 1900 data for currect gmina of respondent 
drop id
merge m:1 gminy_code using  "~/Dropbox/Poland/1900 Prussian Statistics/gminy_code_1900_id_for_kresy_survey_locations.dta"

drop _merge
drop objectid join_count target_fid land
gen id_dr_1900=id
label var id_dr_1900 "map id for 1900 germany"

merge m:1 id using germany1900_religion.dta
**** religion variables from Prussian 1900 census 

drop if _merge==2
drop _merge

sort id
merge id using germany1900_language.dta
**** language variables from Prussian 1900 census 

drop if _merge==2
drop _merge

***** Dealiing with Bogatynia, which was not in prussia: Reichenau-Bogatynia belonged to Zittau, but that Zittau itself was part of Sachsen/Saxony.
***** For Bogatynia, we know the language and religious composition based on Amtshauptmannschaft Zittau to which it belonged: 
***** We have 83.47% Protestant, 16.15% Catholic and <=0.38% Jews and other.

replace protestant1900=  0.8347 if gminy_code==22503
replace catholic1900=0.1615 if gminy_code==22503
replace jews1900 =0.038 if gminy_code==22503
replace orthodox1900 =0 if gminy_code==22503

replace lan_german1900 =0.92339 if gminy_code==22503
replace lan_russian1900=0 if gminy_code==22503
replace lan_lithuanian1900=0 if gminy_code==22503


****************************************************************************************************
******** Merge data for 1931 Poland
*****************************************************************************************************


***** Merge data from 1931 census to each place

gen code_map_1931pow=""
foreach anc in `anc_list1' {
replace code_map_1931pow=`anc'_pow_code1931_use
merge m:1 code_map_1931pow using 1931_Polish_census.dta
keep if _merge==3|_merge==1
drop _merge 
foreach var in in_kresy r_rcatholic_1931pow r_gcatholic_1931pow r_orthodox_1931pow r_jewish_1931pow r_rcatholic_1931rural r_gcatholic_1931rural r_orthodox_1931rural r_jewish_1931rural r_rcatholic_1931urban r_gcatholic_1931urban r_orthodox_1931urban r_jewish_1931urban r_protestant_1931pow r_protestant_1931rural r_protestant_1931urban Lang_polish_1931pow Lang_ukranian_1931pow Lang_bel_1931pow Lang_russian_1931pow Lang_lit_1931pow Lang_german_1931pow Lang_polish_1931rural Lang_ukranian_1931rural Lang_bel_1931rural Lang_russian_1931rural Lang_lit_1931rural Lang_german_1931rural Lang_polish_1931urban Lang_ukranian_1931urban Lang_bel_1931urban Lang_russian_1931urban Lang_lit_1931urban Lang_german_1931urban Lang_jews_1931_pow Lang_jews_1931_rural Lang_jews_1931_urban literate_1931pow readonly_1931pow notliterate_1931pow literate_1931rural readonly_1931rural notliterate_1931rural literate_1931urban readonly_1931urban notliterate_1931urban urbanization_1931 {
rename `var' `anc'_`var'
} 
replace `anc'_data_quality_source=`anc'_data_quality_source+1 if `anc'_r_rcatholic_1931pow!=.|`anc'_r_rcatholic_1931rural!=.|`anc'_r_rcatholic_1931urban!=.
}

********* For localities where the powiat was found, and not locality, use powiaty-level information to infer country of origin: central poland vs. kresy
foreach anc in `anc_list1' {
replace `anc'_origin_country_use="Central Poland" if `anc'_origin_country_use=="SPR"& `anc'_in_kresy==0
replace `anc'_origin_country_use="Kresy"          if `anc'_origin_country_use=="SPR"& `anc'_in_kresy==1

replace `anc'_origin_country_use="WT"             if `anc'_origin_country_use=="Poland"& `anc'_pow_code1931_use==""
replace `anc'_origin_country_use="Central Poland" if `anc'_origin_country_use=="Poland"& `anc'_pow_code1931_use!=""

replace `anc'_origin_country_use="Kresy" if `anc'_in_kresy==1
replace `anc'_origin_country_use="Kresy" if `anc'_pow_code1931_use!=""&(`anc'_origin_country_use=="Byelarus"|`anc'_origin_country_use=="Ukraine"|`anc'_origin_country_use=="Lithuania")
replace `anc'_origin_country_use="" if `anc'_origin_country_use=="SPR"&`anc'_pow_code1931_use==""

}


******** Treat observations in WT. 
******** A couple of people indicated specific places in WT, we assume that they did not know that these places are in WT and not CP

**** locality in WT
replace MMF_origin_country_use="WT" if numer_ankiety==3736
replace FM_origin_country_use="WT" if numer_ankiety==1410
replace MM_origin_country_use="WT" if numer_ankiety==1410
replace MF_origin_country_use="WT" if numer_ankiety==1410
replace FF_origin_country_use="WT" if numer_ankiety==1410
replace MF_origin_country_use="WT" if numer_ankiety==547
replace FF_origin_country_use="WT" if numer_ankiety==547


**** closest city in WT (and we do not know anuthing else)
replace FF_origin_country_use="WT" if numer_ankiety==2634


label define origin_label 1 "lived_in_kresy" 2 "lived_in_central_poland" 

foreach anc in `anc_list1' {
gen `anc'1_from_places=1 if `anc'_origin_country_use=="Kresy"| `anc'_origin_country_use=="Russia"| `anc'_origin_country_use=="Ukraine"| `anc'_origin_country_use=="Byelarus"| `anc'_origin_country_use=="Lithuania"
replace `anc'1_from_places=2 if `anc'_origin_country_use=="Central Poland"
label values `anc'1_from_places origin_label
}


****************************************************************************************************
******** Merge literacy of catholics data from 1921 poland
*****************************************************************************************************

***** Merge data from 1921 census to each place

gen powiaty_code1931=""
foreach anc in `anc_list1' {
replace powiaty_code1931=`anc'_pow_code1931_use
merge m:1 powiaty_code1931 using 1921_census_pow_for_kresy_survey.dta
keep if _merge==3|_merge==1
drop _merge 
foreach var in literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r{
rename `var' `anc'_`var'
} 
}
drop powiaty_code1931


*****************************************************************************************************************



*****************************************************************************************************************
********* use Prussian statistics for 1925 and 1931 to approximate the 1931 ethnic / religious composition for ancestors from WT
*****************************************************************************************************************

***** religion

**** Prussia 1925
dis "Prussia"
foreach anc in `anc_list2' {
foreach level in pow urban rural {
replace `anc'_r_rcatholic_1931`level'=catholic1925 if wt_`anc'1==1|`anc'_origin_country_use=="WT"
replace `anc'_r_jewish_1931`level'=jews1925 if wt_`anc'1==1|`anc'_origin_country_use=="WT"
replace `anc'_r_protestant_1931`level'= protestant1925 if wt_`anc'1==1|`anc'_origin_country_use=="WT"

replace `anc'_r_gcatholic_1931`level'=orthodox1900 if (wt_`anc'1==1|`anc'_origin_country_use=="WT")
replace `anc'_r_orthodox_1931`level'=0 if (wt_`anc'1==1|`anc'_origin_country_use=="WT")&orthodox1900!=.

}
}

**** Gdansk -- take data from Prussia of 1900
dis "Gdansk from places"
foreach anc in `anc_list2' {
foreach level in pow urban rural {
replace `anc'_r_rcatholic_1931`level'=catholic1900 if wt_`anc'1==1&`anc'_r_rcatholic_1931`level'==.
replace `anc'_r_jewish_1931`level'=jews1900 if wt_`anc'1==1&`anc'_r_jewish_1931`level'==.
replace `anc'_r_protestant_1931`level'= protestant1900 if wt_`anc'1==1&`anc'_r_protestant_1931`level'==.
}
}

**** Gdansk from question 1 -- take data from Prussia of 1900
dis "Gdansk from question 1"
foreach anc in `anc_list2' {
foreach level in pow urban rural {
replace `anc'_r_rcatholic_1931`level'=catholic1900 if `anc'1==5
replace `anc'_r_jewish_1931`level'=jews1900 if `anc'1==5
replace `anc'_r_protestant_1931`level'= protestant1900 if `anc'1==5
replace `anc'_r_gcatholic_1931`level'=0 if `anc'1==5&catholic1900!=.
replace `anc'_r_orthodox_1931`level'=orthodox1900  if `anc'1==5
}
replace `anc'_data_quality_source=2002 if `anc'1==5
}



***** languages in Gdansk or WT -- take data from Prussia of 1900

foreach anc in `anc_list2' {
foreach level in pow urban rural {
replace `anc'_Lang_polish_1931`level'=lan_polish1900+lan_kassubian1900+lan_masurish1900 if wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_ukranian_1931`level'=0 if  wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_bel_1931`level' =0 if  wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_russian_1931`level' =lan_russian1900 if  wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_lit_1931`level' =lan_lithuanian1900 if  wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_german_1931`level'=lan_german1900 if   wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_Lang_jews_1931_`level'=0 if wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_in_kresy=0 if  wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
}
}

**** For ancestors in WT, set original location to be equal to the current location (even migration matrix 1950 predicts current allocation, which means that this is a very giid guess)
foreach anc in `anc_list2' {
replace `anc'_pow_code1931_use="" if wt_`anc'1==1|`anc'1==5
replace `anc'_longitude1939_use=longitude_gminy_cent if wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_latitude1939_use=latitude_gminy_cent if wt_`anc'1==1|`anc'1==5|`anc'_origin_country_use=="WT"
replace `anc'_origin_country_use="Gdansk" if `anc'1==5
replace `anc'_origin_country_use="WT" if wt_`anc'1==1
}

foreach anc in `anc_list2' {
replace wt_`anc'1=1 if `anc'_origin_country_use=="WT"
replace `anc'_data_quality_source=2002 if wt_`anc'1==1
}



*****************************************************************************************************************
*********** There are 54 places to the East of Poland in 1931, add ethnic composition data from the Russian Empire from 1897 census 
*****************************************************************************************************************

foreach anc in `anc_list2' {
cap drop rn
gen rn=`anc'_rn
merge m:1 rn using 1897_RussCens_for_kresy_survey.dta

drop   grossregion prov  
keep if _merge==3|_merge==1
foreach var in literate_r not_literate_r higher_educate_r literate_t not_literate_t higher_educate_t literate_u not_literate_u higher_educate_u greek_catholic_r jewish_r orthodox_r protestant_r roman_catholic_r greek_catholic_t jewish_t orthodox_t protestant_t roman_catholic_t greek_catholic_u jewish_u orthodox_u protestant_u roman_catholic_u polish_r ukrainian_r belorussian_r russian_r lithuanian_r german_r jew_r polish_t ukrainian_t belorussian_t russian_t lithuanian_t german_t jew_t polish_u ukrainian_u belorussian_u russian_u lithuanian_u german_u jew_u Rus_urbanization {
rename `var' tmprus_`anc'_`var'
}
drop _merge 
}


**** Russian Empire religions 1897


foreach anc in `anc_list2' {

replace `anc'_r_rcatholic_1931pow  = tmprus_`anc'_roman_catholic_t 	if `anc'_r_rcatholic_1931pow==. 	& tmprus_`anc'_roman_catholic_t 	!=.
replace `anc'_r_jewish_1931pow     = tmprus_`anc'_jewish_t 			if `anc'_r_jewish_1931pow==. 		& tmprus_`anc'_jewish_t				!=. 
replace `anc'_r_protestant_1931pow = tmprus_`anc'_protestant_t 		if `anc'_r_protestant_1931pow ==.	& tmprus_`anc'_protestant_t 		!=.
replace `anc'_r_gcatholic_1931pow  = tmprus_`anc'_greek_catholic_t	if `anc'_r_gcatholic_1931pow==.		& tmprus_`anc'_greek_catholic_t		!=.
replace `anc'_r_orthodox_1931pow   = tmprus_`anc'_orthodox_t		if `anc'_r_orthodox_1931pow==.		& tmprus_`anc'_orthodox_t			!=.

replace `anc'_r_rcatholic_1931urban  = tmprus_`anc'_roman_catholic_u 	if `anc'_r_rcatholic_1931urban==. 		& tmprus_`anc'_roman_catholic_u 	!=.
replace `anc'_r_jewish_1931urban     = tmprus_`anc'_jewish_u 			if `anc'_r_jewish_1931urban==. 			& tmprus_`anc'_jewish_u				!=. 
replace `anc'_r_protestant_1931urban = tmprus_`anc'_protestant_u 		if `anc'_r_protestant_1931urban ==.		& tmprus_`anc'_protestant_u 		!=.
replace `anc'_r_gcatholic_1931urban  = tmprus_`anc'_greek_catholic_u	if `anc'_r_gcatholic_1931urban==.		& tmprus_`anc'_greek_catholic_u		!=.
replace `anc'_r_orthodox_1931urban   = tmprus_`anc'_orthodox_u			if `anc'_r_orthodox_1931urban==.		& tmprus_`anc'_orthodox_u			!=.

replace `anc'_r_rcatholic_1931rural  = tmprus_`anc'_roman_catholic_r 	if `anc'_r_rcatholic_1931rural==. 		& tmprus_`anc'_roman_catholic_r 	!=.
replace `anc'_r_jewish_1931rural     = tmprus_`anc'_jewish_r 			if `anc'_r_jewish_1931rural==. 			& tmprus_`anc'_jewish_r				!=. 
replace `anc'_r_protestant_1931rural = tmprus_`anc'_protestant_r 		if `anc'_r_protestant_1931rural ==.		& tmprus_`anc'_protestant_r 		!=.
replace `anc'_r_gcatholic_1931rural  = tmprus_`anc'_greek_catholic_r	if `anc'_r_gcatholic_1931rural==.		& tmprus_`anc'_greek_catholic_r		!=.
replace `anc'_r_orthodox_1931rural   = tmprus_`anc'_orthodox_r			if `anc'_r_orthodox_1931rural==.		& tmprus_`anc'_orthodox_r			!=.

replace `anc'_data_quality_source=`anc'_data_quality_source+3 if `anc'_r_rcatholic_1931pow  == tmprus_`anc'_roman_catholic_t & tmprus_`anc'_roman_catholic_t 	!=.

}

***** Russian Empire languages 1897

foreach anc in `anc_list2' {

foreach level in pow  {
replace `anc'_Lang_polish_1931`level'    =tmprus_`anc'_polish_t 		if `anc'_Lang_polish_1931`level'==. 	& 	tmprus_`anc'_polish_t		!=.
replace `anc'_Lang_ukranian_1931`level'  =tmprus_`anc'_ukrainian_t		if `anc'_Lang_ukranian_1931`level'==.	&	tmprus_`anc'_ukrainian_t	!=.
replace `anc'_Lang_bel_1931`level' 		 =tmprus_`anc'_belorussian_t	if `anc'_Lang_bel_1931`level'==. 		&  	tmprus_`anc'_belorussian_t 	!=. 
replace `anc'_Lang_russian_1931`level' 	 =tmprus_`anc'_russian_t		if `anc'_Lang_russian_1931`level'==.	& 	tmprus_`anc'_russian_t		!=.
replace `anc'_Lang_lit_1931`level' 		 =tmprus_`anc'_lithuanian_t		if `anc'_Lang_lit_1931`level'==.		& 	tmprus_`anc'_lithuanian_t	!=.
replace `anc'_Lang_german_1931`level'	 =tmprus_`anc'_german_t			if `anc'_Lang_german_1931`level'==.		&	tmprus_`anc'_german_t		!=.
replace `anc'_Lang_jews_1931_`level'	 =tmprus_`anc'_jew_t			if `anc'_Lang_jews_1931_`level'==.		&	tmprus_`anc'_jew_t			!=.
}

foreach level in urban  {
replace `anc'_Lang_polish_1931`level'    =tmprus_`anc'_polish_u 		if `anc'_Lang_polish_1931`level'==. 	& 	tmprus_`anc'_polish_u		!=.
replace `anc'_Lang_ukranian_1931`level'  =tmprus_`anc'_ukrainian_u		if `anc'_Lang_ukranian_1931`level'==.	&	tmprus_`anc'_ukrainian_u	!=.
replace `anc'_Lang_bel_1931`level' 		 =tmprus_`anc'_belorussian_u	if `anc'_Lang_bel_1931`level'==. 		&  	tmprus_`anc'_belorussian_u 	!=. 
replace `anc'_Lang_russian_1931`level' 	 =tmprus_`anc'_russian_u		if `anc'_Lang_russian_1931`level'==.	& 	tmprus_`anc'_russian_u		!=.
replace `anc'_Lang_lit_1931`level' 		 =tmprus_`anc'_lithuanian_u		if `anc'_Lang_lit_1931`level'==.		& 	tmprus_`anc'_lithuanian_u	!=.
replace `anc'_Lang_german_1931`level'	 =tmprus_`anc'_german_u			if `anc'_Lang_german_1931`level'==.		&	tmprus_`anc'_german_u		!=.
replace `anc'_Lang_jews_1931_`level'	 =tmprus_`anc'_jew_u			if `anc'_Lang_jews_1931_`level'==.		&	tmprus_`anc'_jew_u			!=.
}

foreach level in rural  {
replace `anc'_Lang_polish_1931`level'    =tmprus_`anc'_polish_r 		if `anc'_Lang_polish_1931`level'==. 	& 	tmprus_`anc'_polish_r		!=.
replace `anc'_Lang_ukranian_1931`level'  =tmprus_`anc'_ukrainian_r		if `anc'_Lang_ukranian_1931`level'==.	&	tmprus_`anc'_ukrainian_r	!=.
replace `anc'_Lang_bel_1931`level' 		 =tmprus_`anc'_belorussian_r	if `anc'_Lang_bel_1931`level'==. 		&  	tmprus_`anc'_belorussian_r 	!=. 
replace `anc'_Lang_russian_1931`level' 	 =tmprus_`anc'_russian_r		if `anc'_Lang_russian_1931`level'==.	& 	tmprus_`anc'_russian_r		!=.
replace `anc'_Lang_lit_1931`level' 		 =tmprus_`anc'_lithuanian_r		if `anc'_Lang_lit_1931`level'==.		& 	tmprus_`anc'_lithuanian_r	!=.
replace `anc'_Lang_german_1931`level'	 =tmprus_`anc'_german_r			if `anc'_Lang_german_1931`level'==.		&	tmprus_`anc'_german_r		!=.
replace `anc'_Lang_jews_1931_`level'	 =tmprus_`anc'_jew_r			if `anc'_Lang_jews_1931_`level'==.		&	tmprus_`anc'_jew_r			!=.
}
}




drop tmprus_*

*****************************************************************************************************************
********* Add data from Austrian empire 1910 (there are few ancestors from 4 places in the Austro-Hungarian empire):
*****************************************************************************************************************

*** generate a variable with which we can merge:
** NOTE THAT AUSTRIAN PLACES ARE ONLY GIVEN FOR THE FOLLOWING ANC: FF MF FM MM F M FMF MMF FFF MFF

foreach anc in FF MF FM MM F M FMF MMF FFF MFF {
**** var to merge Austrian ethnic composition = the number of row in Table 3
gen `anc'_row_austrian_data_file=.
**** var to merge Austrian literacy = value of runningnr in Table 8
gen `anc'_runningnr=.
}

foreach anc in FF MF{
replace `anc'_row_austrian_data_file=393 if numer_ankiety==770
replace `anc'_runningnr=432 if numer_ankiety==770
}

foreach anc in M{
replace `anc'_row_austrian_data_file=367 if numer_ankiety==1556
replace `anc'_runningnr=424 if numer_ankiety==1556
}

foreach anc in FF MF{
replace `anc'_row_austrian_data_file=367 if numer_ankiety==3979
replace `anc'_runningnr=424 if numer_ankiety==3979
}

foreach anc in FMF MMF{
replace `anc'_row_austrian_data_file=367 if numer_ankiety==1694
replace `anc'_runningnr=424 if numer_ankiety==1694
}

foreach anc in F M{
replace `anc'_row_austrian_data_file=367 if numer_ankiety==1564
replace `anc'_runningnr=424 if numer_ankiety==1564
}

foreach anc in F FFF MFF{
replace `anc'_row_austrian_data_file=367 if numer_ankiety==1694
replace `anc'_runningnr=424 if numer_ankiety==1694
}
 
 
foreach anc in FF MF FM MM{
replace `anc'_row_austrian_data_file= 389 if numer_ankiety==397
replace `anc'_runningnr=430 if numer_ankiety==397
}
 

 foreach anc in FF MF {
replace `anc'_row_austrian_data_file= 389 if numer_ankiety==2140
replace `anc'_runningnr=430 if numer_ankiety==2140
}
 

 foreach anc in FF MF MF MM FM{
replace `anc'_row_austrian_data_file= 389 if numer_ankiety==3301
replace `anc'_runningnr=430 if numer_ankiety==3301
}


foreach anc in F M{
replace `anc'_row_austrian_data_file=11 if numer_ankiety==2781
replace `anc'_runningnr=5000 if numer_ankiety==2781
} 
 
*** The data which are merged in here are generated by  "~/Dropbox/Poland/1910 Austrian Census/add_AH_data_to_kresy_places.do"
 
foreach anc in FF MF FM MM F M FMF MMF FFF MFF {
cap drop row_austrian_data_file

gen row_austrian_data_file=`anc'_row_austrian_data_file
merge m:1 row_austrian_data_file using AH_1910_religions_languages.dta
keep if _merge==3|_merge==1
drop _merge

cap drop runningnr
gen runningnr=`anc'_runningnr
merge m:1 runningnr using AH_1910_literacy.dta
keep if _merge==3|_merge==1
drop _merge 

foreach var in AH_literate_1910 AH_ililiterate_1910 AH_readonly_1910  AH_rel_jewish_1910 AH_rel_rcatholic_1910 AH_rel_protestant_1910 AH_rel_gcatholic_1910 AH_rel_orthodox_1910 AH_Lang_polish_1910 AH_Lang_ukranian_1910 AH_Lang_bel_1910 AH_Lang_russian_1910 AH_Lang_lit_1910 AH_Lang_german_1910 AH_Lang_jews_1910 {
rename `var' tmpAH_`anc'_`var'
}
}

**** AH 1910 religions 
foreach anc in FF MF FM MM F M FMF MMF FFF MFF {
foreach level in pow urban rural {

replace `anc'_r_rcatholic_1931`level'  = tmpAH_`anc'_AH_rel_rcatholic_1910 	if `anc'_r_rcatholic_1931`level'==. 	& tmpAH_`anc'_AH_rel_rcatholic_1910			!=.
replace `anc'_r_jewish_1931`level'     = tmpAH_`anc'_AH_rel_jewish_1910	 	if `anc'_r_jewish_1931`level'==. 		& tmpAH_`anc'_AH_rel_jewish_1910			!=. 
replace `anc'_r_protestant_1931`level' = tmpAH_`anc'_AH_rel_protestant_1910 if `anc'_r_protestant_1931`level' ==.	& tmpAH_`anc'_AH_rel_protestant_1910 		!=.
replace `anc'_r_gcatholic_1931`level'  = tmpAH_`anc'_AH_rel_gcatholic_1910	if `anc'_r_gcatholic_1931`level'==.		& tmpAH_`anc'_AH_rel_gcatholic_1910			!=.
replace `anc'_r_orthodox_1931`level'   = tmpAH_`anc'_AH_rel_orthodox_1910	if `anc'_r_orthodox_1931`level'==.		& tmpAH_`anc'_AH_rel_orthodox_1910			!=.
}
replace `anc'_data_quality_source=`anc'_data_quality_source+4 if `anc'_r_rcatholic_1931pow  == tmpAH_`anc'_AH_rel_rcatholic_1910 &tmpAH_`anc'_AH_rel_rcatholic_1910	!=.

}

**** AH 1910 languages 
foreach anc in FF MF FM MM F M FMF MMF FFF MFF {
foreach level in pow urban rural {
replace `anc'_Lang_polish_1931`level'    =tmpAH_`anc'_AH_Lang_polish_1910 		if `anc'_Lang_polish_1931`level'==. 	& 	tmpAH_`anc'_AH_Lang_polish_1910 			!=.
replace `anc'_Lang_ukranian_1931`level'  =tmpAH_`anc'_AH_Lang_ukranian_1910		if `anc'_Lang_ukranian_1931`level'==.	&	tmpAH_`anc'_AH_Lang_ukranian_1910			!=.
replace `anc'_Lang_bel_1931`level' 		 =tmpAH_`anc'_AH_Lang_bel_1910			if `anc'_Lang_bel_1931`level'==. 		&  	tmpAH_`anc'_AH_Lang_bel_1910 				!=. 
replace `anc'_Lang_russian_1931`level' 	 =tmpAH_`anc'_AH_Lang_russian_1910		if `anc'_Lang_russian_1931`level'==.	& 	tmpAH_`anc'_AH_Lang_russian_1910			!=.
replace `anc'_Lang_lit_1931`level' 		 =tmpAH_`anc'_AH_Lang_lit_1910			if `anc'_Lang_lit_1931`level'==.		& 	tmpAH_`anc'_AH_Lang_lit_1910				!=.
replace `anc'_Lang_german_1931`level'	 =tmpAH_`anc'_AH_Lang_german_1910		if `anc'_Lang_german_1931`level'==.		&	tmpAH_`anc'_AH_Lang_german_1910				!=.
replace `anc'_Lang_jews_1931_`level'	 =tmpAH_`anc'_AH_Lang_jews_1910			if `anc'_Lang_jews_1931_`level'==.		&	tmpAH_`anc'_AH_Lang_jews_1910				!=.
}
}


*** drop the keys for merging : 
foreach anc in FF MF FM MM F M FMF MMF FFF MFF {
drop `anc'_row_austrian_data_file
drop `anc'_runningnr
}

drop tmpAH*

foreach anc in `anc_list1' {
replace `anc'_in_kresy=1 if `anc'_in_kresy==.&(`anc'_origin_country_use=="Kresy"| `anc'_origin_country_use=="Russia"| `anc'_origin_country_use=="Ukraine"| `anc'_origin_country_use=="Byelarus"| `anc'_origin_country_use=="Lithuania")
label var `anc'_in_kresy "in kresy, from places"
}

*****************************************************************************************************************************
*********************** Add woj-level data for 1931 census if locality is not given or was not found, but woj was given
*******************************************************************************************************************************
 
foreach anc in `anc_list' {
capture drop woj_code
gen woj_code=`anc'_woj_code
merge m:1 woj_code using WOJ_1931_census_for_kresy.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in  wr_r_catholic_1931pow wr_g_catholic_1931pow wr_orthodox_1931pow wr_protestant_1931pow wr_jewish_1931pow wL_belorussian_1931pow wLang_russian_1931pow wL_lithuanian_1931pow wLang_german_1931pow wLang_polish_1931pow wLang_ukranian_1931pow wr_r_catholic_1931rural wr_g_catholic_1931rural wr_orthodox_1931rural wr_protestant_1931rural wr_jewish_1931rural wL_belorussian_1931rural wLang_russian_1931rural wL_lithuanian_1931rural wLang_german_1931rural wLang_polish_1931rural wLang_ukranian_1931rural wr_r_catholic_1931urban wr_g_catholic_1931urban wr_orthodox_1931urban wr_protestant_1931urban wr_jewish_1931urban wL_belorussian_1931urban wLang_russian_1931urban wL_lithuanian_1931urban wLang_german_1931urban wLang_polish_1931urban wLang_ukranian_1931urban wliterate_1931pow wreadonly_1931pow wnotliterate_1931pow wliterate_1931rural wreadonly_1931rural wnotliterate_1931rural wliterate_1931urban wreadonly_1931urban wnotliterate_1931urban wLang_jews_1931pow wLang_jews_1931urban wLang_jews_1931rural{
rename `var' W`anc'_`var'
} 
} 

foreach level in pow urban rural {
foreach var in  wr_r_catholic_1931 wr_g_catholic_1931 wr_orthodox_1931 wr_protestant_1931 wr_jewish_1931 wL_belorussian_1931 wLang_russian_1931 wL_lithuanian_1931 wLang_german_1931 wLang_polish_1931 wLang_ukranian_1931  wliterate_1931 wreadonly_1931 wnotliterate_1931 wLang_jews_1931{
rename WA10_1_`var'`level'  WA1_1_`var'`level' 
rename WS10_1_`var'`level'  WS1_1_`var'`level'
rename WS10_2_`var'`level'  WS1_2_`var'`level'  
rename WS10_3_`var'`level'  WS1_3_`var'`level'  
}
}

*** add coordinates of woj 1931 centeroid
foreach anc in `anc_list' {
capture drop woj_code
gen woj_code=`anc'_woj_code
merge m:1 woj_code using woj_1931_centeroids.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in   longitude_cent_woj_1931 latitude_cent_woj_1931{
rename `var' W`anc'_`var'
} 
} 

rename WA10_1_longitude_cent_woj_1931 WA1_1_longitude_cent_woj_1931 
rename WS10_1_longitude_cent_woj_1931 WS1_1_longitude_cent_woj_1931 
rename WS10_2_longitude_cent_woj_1931 WS1_2_longitude_cent_woj_1931 
rename WS10_3_longitude_cent_woj_1931 WS1_3_longitude_cent_woj_1931

rename WA10_1_latitude_cent_woj_1931 WA1_1_latitude_cent_woj_1931 
rename WS10_1_latitude_cent_woj_1931 WS1_1_latitude_cent_woj_1931 
rename WS10_2_latitude_cent_woj_1931 WS1_2_latitude_cent_woj_1931 
rename WS10_3_latitude_cent_woj_1931 WS1_3_latitude_cent_woj_1931

rename A10_1_woj_code  A1_1_woj_code
rename S10_1_woj_code  S1_1_woj_code
rename S10_2_woj_code  S1_2_woj_code
rename S10_3_woj_code  S1_3_woj_code

foreach anc in `anc_list1'{
replace `anc'_longitude1939_use   =W`anc'_longitude_cent_woj_1931 		if `anc'_longitude1939_use ==.		&`anc'_woj_code!=.    	&`anc'_pow_code1931_use==""
replace `anc'_latitude1939_use    =W`anc'_latitude_cent_woj_1931		if `anc'_latitude1939_use==.		&`anc'_woj_code!=.		&`anc'_pow_code1931_use==""
}


*** NEED TO ESTABLISH WHICH WOJ ARE IN KRESY!!!!!! TO BE ABLE TO FILL IN ORIGIN COUNYRY USE

**** replace the 1931 values with woj data with powiaty_use is missing, i.e., we do nto knkow powiat, but know woj

**** literacy woj 1931 data
foreach anc in `anc_list1'{
foreach level in pow urban rural {

replace `anc'_literate_1931`level'   =W`anc'_wliterate_1931`level' 			if `anc'_literate_1931`level'==.		&W`anc'_wliterate_1931`level'!=.     	&`anc'_pow_code1931_use==""
replace `anc'_notliterate_1931`level'=W`anc'_wnotliterate_1931`level'  		if `anc'_notliterate_1931`level'==.		&W`anc'_wnotliterate_1931`level'!=.		&`anc'_pow_code1931_use==""
replace `anc'_readonly_1931`level'   =W`anc'_wreadonly_1931`level'			if `anc'_readonly_1931`level'==.		&W`anc'_wreadonly_1931`level'	!=.		&`anc'_pow_code1931_use==""
}
}


**** religions woj 1931 data
foreach anc in `anc_list1' {
capture drop `anc'_flag_missing
gen `anc'_flag_missing=`anc'_r_rcatholic_1931pow
foreach level in pow urban rural {

replace `anc'_r_rcatholic_1931`level'  = W`anc'_wr_r_catholic_1931`level' 		if `anc'_r_rcatholic_1931`level'==. 	& W`anc'_wr_r_catholic_1931`level'		!=.&`anc'_pow_code1931_use==""
replace `anc'_r_jewish_1931`level'     = W`anc'_wr_jewish_1931`level'	 		if `anc'_r_jewish_1931`level'==. 		& W`anc'_wr_jewish_1931`level'			!=.&`anc'_pow_code1931_use=="" 
replace `anc'_r_protestant_1931`level' = W`anc'_wr_protestant_1931`level'  	 	if `anc'_r_protestant_1931`level' ==.	& W`anc'_wr_protestant_1931`level'		!=.&`anc'_pow_code1931_use==""
replace `anc'_r_gcatholic_1931`level'  = W`anc'_wr_g_catholic_1931`level'		if `anc'_r_gcatholic_1931`level'==.		& W`anc'_wr_g_catholic_1931`level'		!=.&`anc'_pow_code1931_use==""
replace `anc'_r_orthodox_1931`level'   = W`anc'_wr_orthodox_1931`level'			if `anc'_r_orthodox_1931`level'==.		& W`anc'_wr_orthodox_1931`level'		!=.&`anc'_pow_code1931_use==""
}
replace `anc'_data_quality_source=3001 if `anc'_flag_missing==.&`anc'_r_rcatholic_1931pow!=.&`anc'_pow_code1931_use==""
drop *_flag_missing
}



**** languages   woj 1931 data
foreach anc in `anc_list1' {
foreach level in pow urban rural {
replace `anc'_Lang_polish_1931`level'    =W`anc'_wLang_polish_1931`level'			if `anc'_Lang_polish_1931`level'==. 	& 	W`anc'_wLang_polish_1931`level' 			!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_ukranian_1931`level'  =W`anc'_wLang_ukranian_1931`level'			if `anc'_Lang_ukranian_1931`level'==.	&	W`anc'_wLang_ukranian_1931`level'			!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_bel_1931`level' 		 =W`anc'_wL_belorussian_1931`level'			if `anc'_Lang_bel_1931`level'==. 		&  	W`anc'_wL_belorussian_1931`level'			!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_russian_1931`level' 	 =W`anc'_wLang_russian_1931`level'			if `anc'_Lang_russian_1931`level'==.	& 	W`anc'_wLang_russian_1931`level'			!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_lit_1931`level' 		 =W`anc'_wL_lithuanian_1931`level'			if `anc'_Lang_lit_1931`level'==.		& 	W`anc'_wL_lithuanian_1931`level'			!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_german_1931`level'	 =W`anc'_wLang_german_1931`level'			if `anc'_Lang_german_1931`level'==.		&	W`anc'_wLang_german_1931`level'				!=.&`anc'_pow_code1931_use==""
replace `anc'_Lang_jews_1931_`level'	 =W`anc'_wLang_jews_1931`level'				if `anc'_Lang_jews_1931_`level'==.		&	W`anc'_wLang_jews_1931`level'				!=.&`anc'_pow_code1931_use==""


}
}

 drop W*
 
 
 
*****************************************************************************************************************************
********************** Add woj-level data for 1921 census - literacy of catholics
*****************************************************************************************************************************
 
foreach anc in `anc_list1' {
capture drop woj_code
gen woj_code=`anc'_woj_code
merge m:1 woj_code using 1921_census_woj_for_kresy_survey.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in  literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r{
rename `var' W`anc'_`var'
} 
} 

foreach anc in `anc_list1' {
foreach var in  literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r{
replace `anc'_`var'= W`anc'_`var' if W`anc'_`var'!=.&`anc'_`var'==.
}
}

cap drop literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r
drop W*  

 
*****************************************************************************************************************************
********************** Add closest city - woj-level data for 1931 census if we can only identify the location of the closest city (CC). Take the woj in which with closest city is
*****************************************************************************************************************************

*** first fix some of the codes which were not found automatically:

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P0803" if `anc'_pow_code_f_city==""&`anc'8=="GRODNO"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P0803" if `anc'_pow_code_f_city==""&`anc'8=="Grodno"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1406" if `anc'_pow_code_f_city==""&`anc'8=="Dubno"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1403" if `anc'_pow_code_f_city==""&`anc'8=="Kowel"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P0322" if `anc'_pow_code_f_city==""&`anc'8=="Warszawa"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P0322" if `anc'_pow_code_f_city=="P0000"&`anc'8=="Warszawa"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1022" if `anc'_pow_code_f_city==""&`anc'8=="Sambor"
}

replace FFF_pow_code_f_city="P0606" if FFF_pow_code_f_city==""&numer_ankiety==3050

replace FF_pow_code_f_city="P0709" if FF_pow_code_f_city==""&numer_ankiety==2532


foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1013" if `anc'_pow_code_f_city==""&`anc'8=="Lwów"
}

foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1013" if `anc'_pow_code_f_city==""&`anc'8=="LWÓW"
}


foreach anc in `anc_list2' {
replace `anc'_pow_code_f_city="P1013" if `anc'_pow_code_f_city==""&`anc'8=="Lwów??"
}



***** take woj code from powiat of the closest city

foreach anc in `anc_list' {
gen `anc'_woj_code_cc=int(real(regexr(`anc'_pow_code_f_city,"P",""))/100)
}


***** fix the bug, somebody said wolynia in the closest city 
foreach anc in `anc_list' {
replace `anc'_woj_code_cc=11 if `anc'_rn==313
}


**** merge data using woj code from closest city: 
foreach anc in `anc_list' {
capture drop woj_code
gen woj_code=`anc'_woj_code_cc
merge m:1 woj_code using WOJ_1931_census_for_kresy.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in  wr_r_catholic_1931pow wr_g_catholic_1931pow wr_orthodox_1931pow wr_protestant_1931pow wr_jewish_1931pow wL_belorussian_1931pow wLang_russian_1931pow wL_lithuanian_1931pow wLang_german_1931pow wLang_polish_1931pow wLang_ukranian_1931pow wr_r_catholic_1931rural wr_g_catholic_1931rural wr_orthodox_1931rural wr_protestant_1931rural wr_jewish_1931rural wL_belorussian_1931rural wLang_russian_1931rural wL_lithuanian_1931rural wLang_german_1931rural wLang_polish_1931rural wLang_ukranian_1931rural wr_r_catholic_1931urban wr_g_catholic_1931urban wr_orthodox_1931urban wr_protestant_1931urban wr_jewish_1931urban wL_belorussian_1931urban wLang_russian_1931urban wL_lithuanian_1931urban wLang_german_1931urban wLang_polish_1931urban wLang_ukranian_1931urban wliterate_1931pow wreadonly_1931pow wnotliterate_1931pow wliterate_1931rural wreadonly_1931rural wnotliterate_1931rural wliterate_1931urban wreadonly_1931urban wnotliterate_1931urban wLang_jews_1931pow wLang_jews_1931urban wLang_jews_1931rural{
rename `var' W`anc'_`var'
} 
} 

foreach level in pow urban rural {
foreach var in  wr_r_catholic_1931 wr_g_catholic_1931 wr_orthodox_1931 wr_protestant_1931 wr_jewish_1931 wL_belorussian_1931 wLang_russian_1931 wL_lithuanian_1931 wLang_german_1931 wLang_polish_1931 wLang_ukranian_1931  wliterate_1931 wreadonly_1931 wnotliterate_1931 wLang_jews_1931{
rename WA10_1_`var'`level'  WA1_1_`var'`level' 
rename WS10_1_`var'`level'  WS1_1_`var'`level'
rename WS10_2_`var'`level'  WS1_2_`var'`level'  
rename WS10_3_`var'`level'  WS1_3_`var'`level'  
}
}


*** add coordinates of woj of closest city 1931 centeroid
foreach anc in `anc_list' {
capture drop woj_code
gen woj_code=`anc'_woj_code_cc
merge m:1 woj_code using woj_1931_centeroids.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in   longitude_cent_woj_1931 latitude_cent_woj_1931{
rename `var' W`anc'_`var'
} 
} 

rename WA10_1_longitude_cent_woj_1931 WA1_1_longitude_cent_woj_1931 
rename WS10_1_longitude_cent_woj_1931 WS1_1_longitude_cent_woj_1931 
rename WS10_2_longitude_cent_woj_1931 WS1_2_longitude_cent_woj_1931 
rename WS10_3_longitude_cent_woj_1931 WS1_3_longitude_cent_woj_1931

rename WA10_1_latitude_cent_woj_1931 WA1_1_latitude_cent_woj_1931 
rename WS10_1_latitude_cent_woj_1931 WS1_1_latitude_cent_woj_1931 
rename WS10_2_latitude_cent_woj_1931 WS1_2_latitude_cent_woj_1931 
rename WS10_3_latitude_cent_woj_1931 WS1_3_latitude_cent_woj_1931

rename A10_1_woj_code_cc A1_1_woj_code_cc 
rename S10_1_woj_code_cc S1_1_woj_code_cc
rename S10_2_woj_code_cc S1_2_woj_code_cc 
rename S10_3_woj_code_cc S1_3_woj_code_cc


foreach anc in `anc_list1'{
replace `anc'_longitude1939_use   =W`anc'_longitude_cent_woj_1931 		if `anc'_longitude1939_use ==.		&`anc'_woj_code==.  & `anc'_woj_code_cc!=. 	&`anc'_pow_code1931_use==""
replace `anc'_latitude1939_use    =W`anc'_latitude_cent_woj_1931		if `anc'_latitude1939_use==.		&`anc'_woj_code==.	& `anc'_woj_code_cc!=.	&`anc'_pow_code1931_use==""

}





**** replace the 1931 values with woj data with powiaty_use is missing and woj code is missing, but woj_code from CC is not missing, i.e., we do nto knkow powiat, woj, but know woj of closest city

**** literacy woj 1931 data
foreach anc in `anc_list1'{
foreach level in pow urban rural {

replace `anc'_literate_1931`level'   =W`anc'_wliterate_1931`level' 			if `anc'_literate_1931`level'==.		&W`anc'_wliterate_1931`level'!=.     	&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_notliterate_1931`level'=W`anc'_wnotliterate_1931`level'  		if `anc'_notliterate_1931`level'==.		&W`anc'_wnotliterate_1931`level'!=.		&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_readonly_1931`level'   =W`anc'_wreadonly_1931`level'			if `anc'_readonly_1931`level'==.		&W`anc'_wreadonly_1931`level'	!=.		&`anc'_pow_code1931_use=="" &`anc'_woj_code==.

}
}


**** religions  literacy woj 1931 data
foreach anc in `anc_list1' {
foreach level in pow urban rural {

replace `anc'_r_rcatholic_1931`level'  = W`anc'_wr_r_catholic_1931`level' 		if `anc'_r_rcatholic_1931`level'==. 	& W`anc'_wr_r_catholic_1931`level'		!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_r_jewish_1931`level'     = W`anc'_wr_jewish_1931`level'	 		if `anc'_r_jewish_1931`level'==. 		& W`anc'_wr_jewish_1931`level'			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_r_protestant_1931`level' = W`anc'_wr_protestant_1931`level'  	 	if `anc'_r_protestant_1931`level' ==.	& W`anc'_wr_protestant_1931`level'		!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_r_gcatholic_1931`level'  = W`anc'_wr_g_catholic_1931`level'		if `anc'_r_gcatholic_1931`level'==.		& W`anc'_wr_g_catholic_1931`level'		!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_r_orthodox_1931`level'   = W`anc'_wr_orthodox_1931`level'			if `anc'_r_orthodox_1931`level'==.		& W`anc'_wr_orthodox_1931`level'		!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
}
replace `anc'_data_quality_source=4001 if `anc'_r_rcatholic_1931pow == W`anc'_wr_r_catholic_1931pow 	& W`anc'_wr_r_catholic_1931pow		!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.&`anc'_woj_code_cc!=.
}


**** languages    literacy woj 193
foreach anc in `anc_list1' {
foreach level in pow urban rural {
replace `anc'_Lang_polish_1931`level'    =W`anc'_wLang_polish_1931`level'			if `anc'_Lang_polish_1931`level'==. 	& 	W`anc'_wLang_polish_1931`level' 			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_ukranian_1931`level'  =W`anc'_wLang_ukranian_1931`level'			if `anc'_Lang_ukranian_1931`level'==.	&	W`anc'_wLang_ukranian_1931`level'			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_bel_1931`level' 		 =W`anc'_wL_belorussian_1931`level'			if `anc'_Lang_bel_1931`level'==. 		&  	W`anc'_wL_belorussian_1931`level'			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_russian_1931`level' 	 =W`anc'_wLang_russian_1931`level'			if `anc'_Lang_russian_1931`level'==.	& 	W`anc'_wLang_russian_1931`level'			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_lit_1931`level' 		 =W`anc'_wL_lithuanian_1931`level'			if `anc'_Lang_lit_1931`level'==.		& 	W`anc'_wL_lithuanian_1931`level'			!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_german_1931`level'	 =W`anc'_wLang_german_1931`level'			if `anc'_Lang_german_1931`level'==.		&	W`anc'_wLang_german_1931`level'				!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.
replace `anc'_Lang_jews_1931_`level'	 =W`anc'_wLang_jews_1931`level'				if `anc'_Lang_jews_1931_`level'==.		&	W`anc'_wLang_jews_1931`level'				!=.&`anc'_pow_code1931_use=="" &`anc'_woj_code==.


}
}

 drop W*
 
 
*****************************************************************************************************************************
********************** Add closect city woj-level data for 1921 census - literacy of catholics
*****************************************************************************************************************************
 
foreach anc in `anc_list1' {
capture drop woj_code
gen woj_code=`anc'_woj_code_cc
merge m:1 woj_code using 1921_census_woj_for_kresy_survey.dta
keep if _merge==1|_merge==3

drop _merge 
foreach var in  literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r{
rename `var' W`anc'_`var'
} 
} 

foreach anc in `anc_list1' {
foreach var in  literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r{
replace `anc'_`var'= W`anc'_`var' if W`anc'_`var'!=.&`anc'_`var'==.
}
}

cap drop literate_1921_t literate_1921_u literate_1921_r lit_rcath_1921_t lit_rcath_1921_u lit_rcath_1921_r r_catholic_1921_t r_catholic_1921_u r_catholic_1921_r
drop W*  

*** fix the origin country use and the woj code for the places added using woj-lwvwl information

foreach anc in `anc_list2'{

replace `anc'_woj_code=`anc'_woj_code_cc if `anc'_woj_code==.  & `anc'_woj_code_cc!=.

replace `anc'_origin_country_use="Kresy" if (`anc'_woj_code>10&`anc'_woj_code<17)&`anc'_origin_country_use==""
replace `anc'_origin_country_use="Kresy" if `anc'1==1&(`anc'_woj_code==8|`anc'_woj_code==10)&`anc'_origin_country_use==""

replace `anc'_origin_country_use="Central Poland" if ((`anc'_woj_code>0&`anc'_woj_code<8)|`anc'_woj_code==9)&`anc'_origin_country_use==""
replace `anc'_origin_country_use="Central Poland" if `anc'1==2&(`anc'_woj_code==8|`anc'_woj_code==10)&`anc'_origin_country_use==""

replace `anc'_origin_country_use="Kresy" if `anc'_origin_country_use=="Russia"|`anc'_origin_country_use=="Byelarus"|`anc'_origin_country_use=="Lithuania"|`anc'_origin_country_use=="Ukraine"
}

*** for A  and S
foreach anc in A1_1  S1_1 S1_2 S1_3 {

replace `anc'_woj_code=`anc'_woj_code_cc if `anc'_woj_code==.  & `anc'_woj_code_cc!=.

replace `anc'_origin_country_use="Kresy" if (`anc'_woj_code>10&`anc'_woj_code<17)&`anc'_origin_country_use==""
replace `anc'_origin_country_use="Kresy" if `anc'==1&(`anc'_woj_code==8|`anc'_woj_code==10)&`anc'_origin_country_use==""

replace `anc'_origin_country_use="Central Poland" if ((`anc'_woj_code>0&`anc'_woj_code<8)|`anc'_woj_code==9)&`anc'_origin_country_use==""

replace `anc'_origin_country_use="Kresy" if `anc'_origin_country_use=="Russia"|`anc'_origin_country_use=="Byelarus"|`anc'_origin_country_use=="Lithuania"|`anc'_origin_country_use=="Ukraine"
}


foreach anc in `anc_list1'{
replace `anc'_in_kresy=1 if `anc'_origin_country_use=="Kresy"
replace `anc'_in_kresy=0 if `anc'_origin_country_use=="Central Poland"
}



*****************************************************************************************************************
********* Generate averages across all places of orgin of the individual:
*****************************************************************************************************************

**** take an average for religion
foreach level in pow urban rural {
foreach rel in rcatholic gcatholic orthodox jewish protestant { 
egen `rel'_mean1931_`level' = rowmean(R_r_`rel'_1931`level'  F_r_`rel'_1931`level'  M_r_`rel'_1931`level'  FF_r_`rel'_1931`level'  MF_r_`rel'_1931`level'  FM_r_`rel'_1931`level'  MM_r_`rel'_1931`level'  FFF_r_`rel'_1931`level'  MFF_r_`rel'_1931`level'  FMF_r_`rel'_1931`level'  MMF_r_`rel'_1931`level'  FFM_r_`rel'_1931`level'  MFM_r_`rel'_1931`level'  FMM_r_`rel'_1931`level'  MMM_r_`rel'_1931`level'  A1_1_r_`rel'_1931`level' )
label var `rel'_mean1931_`level' "mean share `rel' across origin locations"
}
}

**** take an average for language
foreach level in pow urban rural {
foreach rel in polish bel ukranian russian german lit { 
egen `rel'_mean1931_`level' =rowmean(R_Lang_`rel'_1931`level'  F_Lang_`rel'_1931`level'  M_Lang_`rel'_1931`level'  FF_Lang_`rel'_1931`level'  MF_Lang_`rel'_1931`level'  FM_Lang_`rel'_1931`level'  MM_Lang_`rel'_1931`level'  FFF_Lang_`rel'_1931`level'  MFF_Lang_`rel'_1931`level'  FMF_Lang_`rel'_1931`level'  MMF_Lang_`rel'_1931`level'  FFM_Lang_`rel'_1931`level'  MFM_Lang_`rel'_1931`level'  FMM_Lang_`rel'_1931`level'  MMM_Lang_`rel'_1931`level'  A1_1_Lang_`rel'_1931`level' )
label var `rel'_mean1931_`level' "mean share `rel' across origin locations"
}
}



**** take an average for literacy
foreach level in pow urban rural {
foreach rel in readonly notliterate literate{ 
egen `rel'_mean1931_`level' =rowmean(R_`rel'_1931`level'  F_`rel'_1931`level'  M_`rel'_1931`level'  FF_`rel'_1931`level'  MF_`rel'_1931`level'  FM_`rel'_1931`level'  MM_`rel'_1931`level'  FFF_`rel'_1931`level'  MFF_`rel'_1931`level'  FMF_`rel'_1931`level'  MMF_`rel'_1931`level'  FFM_`rel'_1931`level'  MFM_`rel'_1931`level'  FMM_`rel'_1931`level'  MMM_`rel'_1931`level'  A1_1_`rel'_1931`level' )
label var `rel'_mean1931_`level' "mean share `rel' across origin locations"
}
}


**** Generate temporary dummy for SPR origin, needed to define literacy and urbaniztion means
foreach anc in `anc_list1' {
gen `anc'_spr=1 if (`anc'_in_kresy==1|`anc'_origin_country_use=="Central Poland")
replace `anc'_spr=0 if `anc'_spr==.&`anc'_origin_country_use!=""&`anc'_in_kresy!=.
label var `anc'_spr "origin in SPR"

}

**** take an average for urbanization

foreach rel in urbanization { 
egen `rel'_mean1931 =rowmean(R_`rel'_1931   F_`rel'_1931   M_`rel'_1931   FF_`rel'_1931   MF_`rel'_1931   FM_`rel'_1931   MM_`rel'_1931   FFF_`rel'_1931   MFF_`rel'_1931   FMF_`rel'_1931   MMF_`rel'_1931   FFM_`rel'_1931   MFM_`rel'_1931   FMM_`rel'_1931   MMM_`rel'_1931   A1_1_`rel'_1931  )
label var `rel'_mean1931 "mean share `rel' across origin locations"
}


**** Take an average for spr
egen spr_mean1931 =rowmean(R_spr   F_spr   M_spr   FF_spr   MF_spr   FM_spr   MM_spr   FFF_spr   MFF_spr   FMF_spr   MMF_spr   FFM_spr   MFM_spr   FMM_spr   MMM_spr   A1_1_spr  )
label var spr_mean1931 "SPR origin mean, from places"

**** Take an average for in_kresy
egen PL_kresy_origin_mean =rowmean(R_in_kresy   F_in_kresy   M_in_kresy   FF_in_kresy   MF_in_kresy   FM_in_kresy   MM_in_kresy   FFF_in_kresy   MFF_in_kresy   FMF_in_kresy   MMF_in_kresy   FFM_in_kresy   MFM_in_kresy   FMM_in_kresy   MMM_in_kresy   A1_1_in_kresy  )
label var PL_kresy_origin_mean "kresy origin mean, from places"
label var kresy_origin_mean "kresy origin mean, from anc1"


gen PL_kresy_origin_only =1 if PL_kresy_origin_mean==1
replace PL_kresy_origin_only=0 if PL_kresy_origin_mean!=.&PL_kresy_origin_only==.
label var PL_kresy_origin_only "kresy origin only, from places"
label var kresy_origin_only "kresy origin only, from anc1"

gen PL_kresy_origin =1 if PL_kresy_origin_mean>0&PL_kresy_origin_mean!=.
replace PL_kresy_origin=0 if PL_kresy_origin_mean==0
label var PL_kresy_origin "at least one ancestor from kresy, from places"
label var kresy_origin "at least one ancestor from kresy, from anc1"


*** Replace averages for urbanization and for literacy if some anc are not from SPR, as the data are not comparable then
foreach rel in readonly notliterate literate { 
foreach level in pow urban rural {
replace  `rel'_mean1931_`level' =. if spr_mean1931<1
}
}

replace urbanization_mean1931=. if spr_mean1931<1

*****************************************************************************************************************
********* Generate averages across places depending on whether the ansestor was from rural or urban area:
*****************************************************************************************************************


********* For that generate temp vars which are the product of rural and urban dummy and their respective value of historical variable
********* For religion:
foreach rel in rcatholic gcatholic orthodox jewish protestant { 
foreach anc in `anc_list2' { 
gen `anc'_r_`rel'_1931=`anc'_r_`rel'_1931urban*urban_`anc'2 + `anc'_r_`rel'_1931rural*rural_`anc'2
replace  `anc'_r_`rel'_1931=`anc'_r_`rel'_1931urban if urban_`anc'2==1&`anc'_r_`rel'_1931urban!=.&`anc'_r_`rel'_1931==.
replace `anc'_r_`rel'_1931=`anc'_r_`rel'_1931pow if `anc'_r_`rel'_1931==.&`anc'_r_`rel'_1931pow!=.
label var `anc'_r_`rel'_1931 "`rel' religion before the war for `anc' taking into account rural/urban origin"

}
gen A1_1_r_`rel'_1931=A1_1_r_`rel'_1931urban*urban_A2_1  + A1_1_r_`rel'_1931rural*rural_A2_1
replace  A1_1_r_`rel'_1931=A1_1_r_`rel'_1931urban if urban_A2_1==1&A1_1_r_`rel'_1931urban!=.&A1_1_r_`rel'_1931==.
replace A1_1_r_`rel'_1931=A1_1_r_`rel'_1931pow if A1_1_r_`rel'_1931==.&A1_1_r_`rel'_1931pow!=.

label var A1_1_r_`rel'_1931 "`rel' religion before the war for A1_1 taking into account rural/urban origin"


gen S1_1_r_`rel'_1931=S1_1_r_`rel'_1931urban*urban_S2_1  + S1_1_r_`rel'_1931rural*rural_S2_1
replace  S1_1_r_`rel'_1931=S1_1_r_`rel'_1931urban if urban_S2_1==1&S1_1_r_`rel'_1931urban!=.&S1_1_r_`rel'_1931==.
replace S1_1_r_`rel'_1931=S1_1_r_`rel'_1931pow if S1_1_r_`rel'_1931==.&S1_1_r_`rel'_1931pow!=.

label var S1_1_r_`rel'_1931 "`rel' religion before the war for S1_1 taking into account rural/urban origin"


gen S1_2_r_`rel'_1931=S1_2_r_`rel'_1931urban*urban_S2_2  + S1_2_r_`rel'_1931rural*rural_S2_2
replace  S1_2_r_`rel'_1931=S1_2_r_`rel'_1931urban if urban_S2_2==1&S1_2_r_`rel'_1931urban!=.&S1_2_r_`rel'_1931==.
replace S1_2_r_`rel'_1931=S1_2_r_`rel'_1931pow if S1_2_r_`rel'_1931==.&S1_2_r_`rel'_1931pow!=.

label var S1_2_r_`rel'_1931 "`rel' religion before the war for S1_2 taking into account rural/urban origin"


gen S1_3_r_`rel'_1931=S1_3_r_`rel'_1931urban*urban_S2_3  + S1_3_r_`rel'_1931rural*rural_S2_3
replace  S1_3_r_`rel'_1931=S1_3_r_`rel'_1931urban if urban_S2_3==1&S1_3_r_`rel'_1931urban!=.&S1_3_r_`rel'_1931==.
replace S1_3_r_`rel'_1931=S1_3_r_`rel'_1931pow if S1_3_r_`rel'_1931==.&S1_3_r_`rel'_1931pow!=.

label var S1_3_r_`rel'_1931 "`rel' religion before the war for S1_3 taking into account rural/urban origin"

}



********* For language:
foreach lang in polish bel ukranian russian german lit { 
foreach anc in `anc_list2' { 
gen `anc'_Lang_`lang'_1931 =`anc'_Lang_`lang'_1931urban*urban_`anc'2 +  `anc'_Lang_`lang'_1931rural*rural_`anc'2
replace `anc'_Lang_`lang'_1931 =`anc'_Lang_`lang'_1931urban if urban_`anc'2==1& `anc'_Lang_`lang'_1931==.&`anc'_Lang_`lang'_1931urban!=.
replace `anc'_Lang_`lang'_1931=`anc'_Lang_`lang'_1931pow if `anc'_Lang_`lang'_1931==.&`anc'_Lang_`lang'_1931pow!=.
label var `anc'_Lang_`lang'_1931 "`lang' lang before the war for `anc' taking into account rural/urban"
}

gen A1_1_Lang_`lang'_1931=A1_1_Lang_`lang'_1931urban*urban_A2_1 +  A1_1_Lang_`lang'_1931rural*rural_A2_1
replace A1_1_Lang_`lang'_1931 =A1_1_Lang_`lang'_1931urban if urban_A2_1==1& A1_1_Lang_`lang'_1931==.&A1_1_Lang_`lang'_1931urban!=.
replace A1_1_Lang_`lang'_1931=A1_1_Lang_`lang'_1931pow if A1_1_Lang_`lang'_1931==.&A1_1_Lang_`lang'_1931pow!=.

label var A1_1_Lang_`lang'_1931 "`lang' lang before the war for A1_1 taking into account rural/urban"


gen S1_1_Lang_`lang'_1931=S1_1_Lang_`lang'_1931urban*urban_S2_1 +  S1_1_Lang_`lang'_1931rural*rural_S2_1
replace S1_1_Lang_`lang'_1931 =S1_1_Lang_`lang'_1931urban if urban_A2_1==1& S1_1_Lang_`lang'_1931==.&S1_1_Lang_`lang'_1931urban!=.
replace S1_1_Lang_`lang'_1931 =S1_1_Lang_`lang'_1931pow if S1_1_Lang_`lang'_1931==.&S1_1_Lang_`lang'_1931pow!=.

label var S1_1_Lang_`lang'_1931 "`lang' lang before the war for S1_1 taking into account rural/urban"

gen S1_2_Lang_`lang'_1931=S1_2_Lang_`lang'_1931urban*urban_S2_2 +  S1_2_Lang_`lang'_1931rural*rural_S2_2
replace S1_2_Lang_`lang'_1931 =S1_2_Lang_`lang'_1931urban if urban_S2_2==1& S1_2_Lang_`lang'_1931==.&S1_2_Lang_`lang'_1931urban!=.
replace S1_2_Lang_`lang'_1931 =S1_2_Lang_`lang'_1931pow if S1_2_Lang_`lang'_1931==.&S1_2_Lang_`lang'_1931pow!=.

label var S1_2_Lang_`lang'_1931 "`lang' lang before the war for S1_2 taking into account rural/urban"

gen S1_3_Lang_`lang'_1931=S1_3_Lang_`lang'_1931urban*urban_S2_3 +  S1_3_Lang_`lang'_1931rural*rural_S2_3
replace S1_3_Lang_`lang'_1931 =S1_3_Lang_`lang'_1931urban if urban_S2_3==1& S1_3_Lang_`lang'_1931==.&S1_3_Lang_`lang'_1931urban!=.
replace S1_3_Lang_`lang'_1931 =S1_3_Lang_`lang'_1931pow if S1_3_Lang_`lang'_1931==.&S1_3_Lang_`lang'_1931pow!=.

label var S1_3_Lang_`lang'_1931 "`lang' lang before the war for S1_3 taking into account rural/urban"
}

********* For literacy:
foreach lit in notliterate literate readonly{ 
foreach anc in `anc_list2' { 
gen `anc'_`lit'_1931 =`anc'_`lit'_1931urban*urban_`anc'2 +   `anc'_`lit'_1931rural*rural_`anc'2
replace `anc'_`lit'_1931 =`anc'_`lit'_1931urban if urban_`anc'2==1&`anc'_`lit'_1931==.&`anc'_`lit'_1931urban !=.
replace `anc'_`lit'_1931= `anc'_`lit'_1931pow if  `anc'_`lit'_1931==.&`anc'_`lit'_1931pow!=.
label var `anc'_`lit'_1931 "sh `lit' before the war for `anc' taking into account rural/urban"

}
gen A1_1_`lit'_1931=A1_1_`lit'_1931urban*urban_A2_1 +   A1_1_`lit'_1931rural*rural_A2_1
replace A1_1_`lit'_1931 =A1_1_`lit'_1931urban if urban_A2_1==1&A1_1_`lit'_1931==.&A1_1_`lit'_1931urban !=.
replace A1_1_`lit'_1931 = A1_1_`lit'_1931pow if  A1_1_`lit'_1931==.&A1_1_`lit'_1931pow!=.
label var A1_1_`lit'_1931 "sh `lit' before the war for `anc' taking into account rural/urban"

gen S1_1_`lit'_1931=S1_1_`lit'_1931urban*urban_S2_1 +   S1_1_`lit'_1931rural*rural_S2_1
replace S1_1_`lit'_1931 =S1_1_`lit'_1931urban if urban_S2_1==1&S1_1_`lit'_1931==.&S1_1_`lit'_1931urban !=.
replace S1_1_`lit'_1931 = S1_1_`lit'_1931pow if  S1_1_`lit'_1931==.&S1_1_`lit'_1931pow!=.
label var S1_1_`lit'_1931 "sh `lit' before the war for `anc' taking into account rural/urban"

gen S1_2_`lit'_1931=S1_2_`lit'_1931urban*urban_S2_1 +   S1_2_`lit'_1931rural*rural_S2_1
replace S1_2_`lit'_1931 =S1_2_`lit'_1931urban if urban_S2_1==1&S1_2_`lit'_1931==.&S1_2_`lit'_1931urban !=.
replace S1_2_`lit'_1931 = S1_2_`lit'_1931pow if  S1_2_`lit'_1931==.&S1_2_`lit'_1931pow!=.
label var S1_2_`lit'_1931 "sh `lit' before the war for `anc' taking into account rural/urban"

gen S1_3_`lit'_1931=S1_3_`lit'_1931urban*urban_S2_1 +   S1_3_`lit'_1931rural*rural_S2_1
replace S1_3_`lit'_1931 =S1_3_`lit'_1931urban if urban_S2_1==1&S1_3_`lit'_1931==.&S1_3_`lit'_1931urban !=.
replace S1_3_`lit'_1931 = S1_3_`lit'_1931pow if  S1_3_`lit'_1931==.&S1_3_`lit'_1931pow!=.
label var S1_3_`lit'_1931 "sh `lit' before the war for `anc' taking into account rural/urban"



}



********* For 1921:
foreach lit in literate  lit_rcath r_catholic { 
foreach anc in `anc_list2' { 
gen `anc'_`lit'_1921 =`anc'_`lit'_1921_u*urban_`anc'2 +   `anc'_`lit'_1921_r*rural_`anc'2
replace `anc'_`lit'_1921 =`anc'_`lit'_1921_u if urban_`anc'2==1&`anc'_`lit'_1921==.&`anc'_`lit'_1921_u !=.
replace `anc'_`lit'_1921= `anc'_`lit'_1921_t if  `anc'_`lit'_1921==.&`anc'_`lit'_1921_t!=.
}
gen A1_1_`lit'_1921=A1_1_`lit'_1921_u*urban_A2_1 +   A1_1_`lit'_1921_r*rural_A2_1
replace A1_1_`lit'_1921 =A1_1_`lit'_1921_u if urban_A2_1==1&A1_1_`lit'_1921==.&A1_1_`lit'_1921_u !=.
replace A1_1_`lit'_1921 = A1_1_`lit'_1921_t if  A1_1_`lit'_1921==.&A1_1_`lit'_1921_t!=.

gen S1_1_`lit'_1921=S1_1_`lit'_1921_u*urban_S2_1 +   S1_1_`lit'_1921_r*rural_S2_1
replace S1_1_`lit'_1921 =S1_1_`lit'_1921_u if urban_S2_1==1&S1_1_`lit'_1921==.&S1_1_`lit'_1921_u !=.
replace S1_1_`lit'_1921 = S1_1_`lit'_1921_t if  S1_1_`lit'_1921==.&S1_1_`lit'_1921_t!=.

gen S1_2_`lit'_1921=S1_2_`lit'_1921_u*urban_S2_1 +   S1_2_`lit'_1921_r*rural_S2_1
replace S1_2_`lit'_1921 =S1_2_`lit'_1921_u if urban_S2_1==1&S1_2_`lit'_1921==.&S1_2_`lit'_1921_u !=.
replace S1_2_`lit'_1921 = S1_2_`lit'_1921_t if  S1_2_`lit'_1921==.&S1_2_`lit'_1921_t!=.

gen S1_3_`lit'_1921=S1_3_`lit'_1921_u*urban_S2_1 +   S1_3_`lit'_1921_r*rural_S2_1
replace S1_3_`lit'_1921 =S1_3_`lit'_1921_u if urban_S2_1==1&S1_3_`lit'_1921==.&S1_3_`lit'_1921_u !=.
replace S1_3_`lit'_1921 = S1_3_`lit'_1921_t if  S1_3_`lit'_1921==.&S1_3_`lit'_1921_t!=.

}


*********************************************

**** take an average for religion of places, taking urban-rural dimension into account
foreach rel in rcatholic gcatholic orthodox jewish protestant { 
egen `rel'_mean1931 = rowmean( R_r_`rel'_1931  F_r_`rel'_1931  M_r_`rel'_1931  FF_r_`rel'_1931  MF_r_`rel'_1931  FM_r_`rel'_1931  MM_r_`rel'_1931  FFF_r_`rel'_1931  MFF_r_`rel'_1931  FMF_r_`rel'_1931  MMF_r_`rel'_1931 FFM_r_`rel'_1931  MFM_r_`rel'_1931  FMM_r_`rel'_1931  MMM_r_`rel'_1931  A1_1_r_`rel'_1931  ) 
label var `rel'_mean1931 "mean share `rel' across origin locations taking urban-rural into account"
}



**** take an average for language of places, taking urban-rural dimension into account
foreach rel in polish bel ukranian russian german lit { 
egen `rel'_mean1931 =rowmean( R_Lang_`rel'_1931  F_Lang_`rel'_1931  M_Lang_`rel'_1931  FF_Lang_`rel'_1931  MF_Lang_`rel'_1931  FM_Lang_`rel'_1931  MM_Lang_`rel'_1931  FFF_Lang_`rel'_1931  MFF_Lang_`rel'_1931  FMF_Lang_`rel'_1931  MMF_Lang_`rel'_1931  FFM_Lang_`rel'_1931  MFM_Lang_`rel'_1931  FMM_Lang_`rel'_1931  MMM_Lang_`rel'_1931   A1_1_Lang_`rel'_1931  )
label var `rel'_mean1931 "mean share `rel' across origin locations taking urban-rural into account"
}



**** take an average for literacy of places, taking urban-rural dimension into account
foreach rel in  notliterate literate readonly{ 
egen `rel'_mean1931 =rowmean( R_`rel'_1931  F_`rel'_1931  M_`rel'_1931  FF_`rel'_1931  MF_`rel'_1931  FM_`rel'_1931  MM_`rel'_1931  FFF_`rel'_1931  MFF_`rel'_1931  FMF_`rel'_1931  MMF_`rel'_1931  FFM_`rel'_1931  MFM_`rel'_1931  FMM_`rel'_1931  MMM_`rel'_1931  A1_1_`rel'_1931   )
label var `rel'_mean1931 "mean share `rel' across origin locations taking urban-rural into account"
}


**** take an average for 1921 data, taking urban-rural dimension into account
foreach rel in  literate  lit_rcath r_catholic{ 
egen `rel'_mean1921 =rowmean( R_`rel'_1921  F_`rel'_1921  M_`rel'_1921  FF_`rel'_1921  MF_`rel'_1921  FM_`rel'_1921  MM_`rel'_1921  FFF_`rel'_1921  MFF_`rel'_1921  FMF_`rel'_1921  MMF_`rel'_1921  FFM_`rel'_1921  MFM_`rel'_1921  FMM_`rel'_1921  MMM_`rel'_1921  A1_1_`rel'_1921   )
label var `rel'_mean1921 "mean `rel' 1921 across origin locations taking urban-rural into account"
}


*** Replace averages for urbanization and for literacy if some anc are not from SPR, as the data are not comparable then
foreach rel in notliterate literate readonly{ 
replace  `rel'_mean1931 =. if spr_mean1931<1
}

*** Replace averages for urbanization and for literacy if some anc are not from SPR, as the data are not comparable then
foreach var in literate_mean1921 lit_rcath_mean1921 r_catholic_mean1921{ 
replace  `var' =. if spr_mean1931<1
}



replace urbanization_mean1931=. if spr_mean1931<1

*********************************************
**** how many data points are in the mean for religion -- take catholics

foreach rel in rcatholic{ 
egen rel_non_missing  = rownonmiss( R_r_`rel'_1931  F_r_`rel'_1931  M_r_`rel'_1931  FF_r_`rel'_1931  MF_r_`rel'_1931  FM_r_`rel'_1931  MM_r_`rel'_1931  FFF_r_`rel'_1931  MFF_r_`rel'_1931  FMF_r_`rel'_1931  MMF_r_`rel'_1931 FFM_r_`rel'_1931  MFM_r_`rel'_1931  FMM_r_`rel'_1931  MMM_r_`rel'_1931   A1_1_r_`rel'_1931  )
}
label var rel_non_missing "non-missing religions"


**** how many data points are in the mean for languages -- take polish
foreach rel in polish  { 
egen lang_non_missing =rownonmiss( R_Lang_`rel'_1931  F_Lang_`rel'_1931  M_Lang_`rel'_1931  FF_Lang_`rel'_1931  MF_Lang_`rel'_1931  FM_Lang_`rel'_1931  MM_Lang_`rel'_1931  FFF_Lang_`rel'_1931  MFF_Lang_`rel'_1931  FMF_Lang_`rel'_1931  MMF_Lang_`rel'_1931  FFM_Lang_`rel'_1931  MFM_Lang_`rel'_1931  FMM_Lang_`rel'_1931  MMM_Lang_`rel'_1931  A1_1_Lang_`rel'_1931 )
}
label var lang_non_missing "non-missing languages"


*** R13==2- grand parents -- this was a mistake, one should just go directly to grand parents level, there are 2 cases like this
replace R13=. if numer_ankiety==3759| numer_ankiety==3257
replace Q0a=2 if numer_ankiety==3257|numer_ankiety==3759
replace Q0b=2 if numer_ankiety==3257|numer_ankiety==3759
replace Q0c=1 if numer_ankiety==3257|numer_ankiety==3759

**** generate the share of non-missings
foreach data_type in rel lang{
gen sh_`data_type'_non_missing=`data_type'_non_missing if Q0a==1&M13==.&MM13==.&R13==.
replace  sh_`data_type'_non_missing=`data_type'_non_missing/2 if Q0b==1&M13==.&MM13==.&R13==.
replace sh_`data_type'_non_missing=`data_type'_non_missing/4 if Q0c==1&M13==.&MM13==.&R13==.
replace sh_`data_type'_non_missing=`data_type'_non_missing/8 if Q0d==1&M13==.&MM13==.&R13==.
replace sh_`data_type'_non_missing=`data_type'_non_missing/16 if Q0e==1&M13==.&MM13==.&R13==.
}

*** After correcting 2 mistakes (see above) R13 is always missing
*** M13 =2 - grand parents; 3 - great grand parents, 4 - great great grand parents
*** M13 =                   3 - great grand parents, 4 - great great grand parents


gen MMM13=.
replace MMM13=4 if MMM1!=.&A1_1==1
order MMM13, after(MMM12) 
label var MMM13 "To which generation belonged the person living permanently in Kresy in 1939"


foreach data_type in rel lang{

*** parents and grand parents (2+4):
replace sh_`data_type'_non_missing=`data_type'_non_missing/6      if Q0b==1& M13==2& MM13==.&MMM13==.
*** parents and great grand parents (2+8):
replace sh_`data_type'_non_missing=`data_type'_non_missing/10     if Q0b==1& M13==3& MM13==.&MMM13==.
*** parents and great great grand parents  (2+3):
replace sh_`data_type'_non_missing=`data_type'_non_missing/5      if Q0b==1& M13==4& MM13==.&MMM13==.

*** parents and grand parents and and great grand parents (2+4+8):
replace sh_`data_type'_non_missing=`data_type'_non_missing/14     if Q0b==1& M13==2& MM13==3&MMM13==.

*** grand parents and and great grand parents (4+8):
replace sh_`data_type'_non_missing=`data_type'_non_missing/12     if Q0c==1& MM13==3&MMM13==.
*** grand parents and and great great grand parents (4+3):
replace sh_`data_type'_non_missing=`data_type'_non_missing/7	  if Q0c==1& MM13==4&MMM13==.

*** great grand parents and great great grand parents (8+3):
replace sh_`data_type'_non_missing=`data_type'_non_missing/11	  if Q0d==1& MMM13==4


*** parents and grand parents and great grand parents and great great grand parents (2+4+8+3):
replace sh_`data_type'_non_missing=`data_type'_non_missing/17     if Q0b==1& M13==2& MM13==3&MMM13==4
}




replace lang_non_missing =. if sh_lang_non_missing==.
replace rel_non_missing =. if sh_rel_non_missing==.

label var sh_lang_non_missing "share of ancestors on whom we have the data on languages"
label var sh_rel_non_missing "share of ancestors on whom we have the data on religious"

*****************************************************************************************************************
********* GENERATE VARIABLE TO KNOW HOW SURE WE ARE OF THE MEAN ORIGIN DATA
*****************************************************************************************************************


egen average_anc_quality = rowmean(R_data_quality_source F_data_quality_source M_data_quality_source FF_data_quality_source MF_data_quality_source FM_data_quality_source MM_data_quality_source FFF_data_quality_source MFF_data_quality_source FMF_data_quality_source MMF_data_quality_source FFM_data_quality_source MFM_data_quality_source FMM_data_quality_source MMM_data_quality_source A1_1_data_quality_source ) 
label var average_anc_quality  "average quality of data on ancestors: 1001 is the best - larger - worse"


rename lit_mean1931 lituanian_mean1931


**********************************************
compress

cap drop s_readonly_mean*
cap drop s_gcatholic_mean*

rename A10_1_rn A1_1_rn
rename S10_1_rn S1_1_rn
rename S10_2_rn S1_2_rn
rename S10_3_rn S1_3_rn

drop *_country_f_loc *_country_code_f_loc
drop *_pow_code_f_city *_pow_code_from_loc
drop *country_code_f_cc *country_f_cc
drop forced_one_atleast forced_mean forced_missing forced_only
drop id type id_dr_1900 name1900
drop *from_places
drop map_powiaty_code_1931
drop row_austrian_data_file runningnr *_woj_code_cc
drop *_rn
drop code_map_1931pow
drop woj_code
cap drop r_protestant_reformed_* r_protestant_lutherian_*
drop powiaty_code_1931



cap drop Lang_ruthenian_1931pow Lang_ruthenian_1931rural Lang_ruthenian_1931urban 
drop *Lang_jews_1931_pow *Lang_jews_1931_rural *Lang_jews_1931_urban

foreach anc in `anc_list1'{
drop `anc'_spr
}


foreach anc in `anc_list1'{
label var `anc'_r_protestant_1931pow "pow r_protestant_1931"
label var `anc'_r_protestant_1931rural "rural r_protestant_1931" 
label var `anc'_r_protestant_1931urban "urban r_protestant_1931"
}



**** condition to get to polish data: (FF_data_quality_source-int(FF_data_quality_source/10)*10)==1

foreach var in notliterate_1931pow  literate_1931pow readonly_1931pow	Lang_ukranian_1931pow	Lang_german_1931pow	Lang_lit_1931pow	Lang_russian_1931pow	Lang_bel_1931pow	Lang_polish_1931pow	r_protestant_1931pow	r_jewish_1931pow	r_orthodox_1931pow	r_gcatholic_1931pow	r_rcatholic_1931pow notliterate_1931rural  literate_1931rural readonly_1931rural	Lang_ukranian_1931rural	Lang_german_1931rural	Lang_lit_1931rural	Lang_russian_1931rural	Lang_bel_1931rural	Lang_polish_1931rural	r_protestant_1931rural	r_jewish_1931rural	r_orthodox_1931rural	r_gcatholic_1931rural	r_rcatholic_1931rural 	notliterate_1931urban  literate_1931urban	readonly_1931urban Lang_ukranian_1931urban	Lang_german_1931urban	Lang_lit_1931urban	Lang_russian_1931urban	Lang_bel_1931urban	Lang_polish_1931urban	r_protestant_1931urban	r_jewish_1931urban	r_orthodox_1931urban	r_gcatholic_1931urban	r_rcatholic_1931urban  urbanization_1931	notliterate_1931  literate_1931	readonly_1931 Lang_ukranian_1931	Lang_german_1931	Lang_lit_1931	Lang_russian_1931	Lang_bel_1931	Lang_polish_1931	r_protestant_1931	r_jewish_1931	r_orthodox_1931	r_gcatholic_1931	r_rcatholic_1931 	in_kresy pow_code1931_use longitude1939_use latitude1939_use data_quality_source {
foreach anc in S1_3  S1_2 S1_1 A1_1	MMM	FMM	MFM	FFM	MMF	FMF	MFF	FFF	MM	FM	MF	FF	M	F	R {
order `anc'_`var', after(S10_3_abroad)
}
}

foreach anc in S1_3  S1_2 S1_1 A1_1	MMM	FMM	MFM	FFM	MMF	FMF	MFF	FFF	MM	FM	MF	FF	M	F	R {
order `anc'_origin_country_use, after(S1_3_in_kresy)
}

foreach var in urbanization_mean1931 readonly_mean1931	literate_mean1931	notliterate_mean1931	lituanian_mean1931	german_mean1931	russian_mean1931	ukranian_mean1931	bel_mean1931	polish_mean1931	protestant_mean1931	jewish_mean1931	orthodox_mean1931	gcatholic_mean1931	rcatholic_mean1931 {
order `var', after(S1_3_notliterate_1931pow)
}

foreach var in readonly_mean1931	literate_mean1931	notliterate_mean1931 lit_mean1931	german_mean1931	russian_mean1931	ukranian_mean1931	bel_mean1931	polish_mean1931	protestant_mean1931	jewish_mean1931	orthodox_mean1931	gcatholic_mean1931	rcatholic_mean1931 {
order `var'_urban, after(readonly_mean1931)
}

foreach var in readonly_mean1931	literate_mean1931	notliterate_mean1931 lit_mean1931	german_mean1931	russian_mean1931	ukranian_mean1931	bel_mean1931	polish_mean1931	protestant_mean1931	jewish_mean1931	orthodox_mean1931	gcatholic_mean1931	rcatholic_mean1931 {
order `var'_rural, after(readonly_mean1931_urban)
}

foreach var in readonly_mean1931	literate_mean1931	notliterate_mean1931 lit_mean1931	german_mean1931	russian_mean1931	ukranian_mean1931	bel_mean1931	polish_mean1931	protestant_mean1931	jewish_mean1931	orthodox_mean1931	gcatholic_mean1931	rcatholic_mean1931 {
order `var'_pow, after(readonly_mean1931_rural)
}

foreach var in  average_anc_quality sh_lang_non_missing sh_rel_non_missing lang_non_missing rel_non_missing spr_mean1931 PL_kresy_origin PL_kresy_origin_only PL_kresy_origin_mean {
order `var', after(S1_3_notliterate_1931pow)
}

order urbanization_mean1931, before(rcatholic_mean1931_urban)

foreach var in rcatholic_mean1931 gcatholic_mean1931 orthodox_mean1931 jewish_mean1931 protestant_mean1931 {
rename `var' rel_`var'
rename `var'_pow rel_`var'_pow
rename `var'_urban rel_`var'_urban
rename `var'_rural rel_`var'_rural
}

foreach var in polish_mean1931 bel_mean1931 ukranian_mean1931 russian_mean1931 german_mean1931 lituanian_mean1931 {
rename `var' lang_`var'
}

foreach var in polish_mean1931 bel_mean1931 ukranian_mean1931 russian_mean1931 german_mean1931 lit_mean1931 {
rename `var'_pow rel_`var'_pow
rename `var'_urban rel_`var'_urban
rename `var'_rural rel_`var'_rural
}


rename A10_1_abroad A1_1_abroad
rename S10_1_abroad S1_1_abroad 
rename S10_2_abroad S1_2_abroad 
rename S10_3_abroad S1_3_abroad

order central_poland_* , after(kresy_origin1)
order wt_* , after(central_poland_A1_3)
order abroad_* , after(wt_A1_3)
order rural_*, after(abroad_A1_3)
order urban_*, after(rural_S2_3)
order ukraine_*, after(urban_S2_3) 
order belorussia_*, after(urban_S2_3) 
order lithuania_*, after(urban_S2_3) 
order *_abroad, after(urban_S2_3) 
order *_forced, after(ukraine_one_atleast) 


foreach var in kresy_A1_3 kresy_A1_2 kresy_A1_1 kresy_MMM1 kresy_FMM1 kresy_MFM1 kresy_FFM1 kresy_MMF1 kresy_FMF1 kresy_MFF1 kresy_FFF1 kresy_MM1 kresy_FM1 kresy_MF1 kresy_FF1 kresy_M1 kresy_F1 kresy_R1 {
order `var' , after(lan_not_german1900)
label var `var'  "Kresy from anc1"
}




**** Generate  dummy for WT origin, needed to define mean WT
foreach anc in `anc_list1' {
gen `anc'_WT=1 if (`anc'_origin_country_use=="WT")|(`anc'_origin_country_use=="Gdansk")
replace `anc'_WT=0 if `anc'_WT==.&`anc'_origin_country_use!=""
label var `anc'_WT "anc origin in WT, from places and anc1"
}



**** Take an average for WT
egen PL_wt_origin_mean =rowmean(R_WT   F_WT   M_WT   FF_WT   MF_WT   FM_WT   MM_WT   FFF_WT   MFF_WT   FMF_WT   MMF_WT   FFM_WT   MFM_WT   FMM_WT   MMM_WT   A1_1_WT  )
label var PL_wt_origin_mean "WT origin mean, from places and anc1"
label var wt_origin_mean "WT origin mean, from anc1"


gen PL_wt_origin_only =1 if PL_wt_origin_mean==1
replace PL_wt_origin_only=0 if PL_wt_origin_mean!=.&PL_wt_origin_only==.
label var PL_wt_origin_only "WT origin only, from places and anc1"
label var wt_origin_only "WT origin only, from anc1"

gen PL_wt_origin =1 if PL_wt_origin_mean>0&PL_kresy_origin_mean!=.
replace PL_wt_origin=0 if PL_wt_origin_mean==0
label var PL_wt_origin "at least one ancestor from WT, from places and anc1"
label var wt_origin "at least one ancestor from WT, from anc1"


**************************

**** Generate  dummy for CP origin, needed to define mean WT
foreach anc in `anc_list1' {
gen `anc'_CP=1 if (`anc'_origin_country_use=="Central Poland")
replace `anc'_CP=0 if `anc'_CP==.&`anc'_origin_country_use!=""
label var `anc'_CP "anc origin in CP, from places"
}



**** Take an average for CP
egen PL_central_poland_origin_mean =rowmean(R_CP   F_CP   M_CP   FF_CP   MF_CP   FM_CP   MM_CP   FFF_CP   MFF_CP   FMF_CP   MMF_CP   FFM_CP   MFM_CP   FMM_CP   MMM_CP   A1_1_CP  )
label var PL_central_poland_origin_mean "CP origin mean, from places"
label var central_poland_origin_mean "CP origin mean, from anc1"


gen PL_central_poland_origin_only =1 if PL_central_poland_origin_mean==1
replace PL_central_poland_origin_only=0 if PL_central_poland_origin_mean!=.&PL_central_poland_origin_only==.
label var PL_central_poland_origin_only "CP origin only, from places"
label var central_poland_origin_only "CP origin only, from anc1"

gen PL_central_poland_origin =1 if PL_central_poland_origin_mean>0&PL_kresy_origin_mean!=.
replace PL_central_poland_origin=0 if PL_central_poland_origin_mean==0
label var PL_central_poland_origin "at least one ancestor from CP, from places"
label var central_poland_origin "at least one ancestor from CP, from anc1"

foreach anc in `anc_list1' {
gen `anc'_woj_code_from_pow=int(real(regexr(`anc'_pow_code1931_use,"P",""))/100)
replace `anc'_woj_code=`anc'_woj_code_from_pow if `anc'_woj_code_from_pow!=.&`anc'_pow_code1931_use!="P1000"
replace `anc'_woj_code=3 if `anc'_pow_code1931_use=="P1000"
drop `anc'_woj_code_from_pow
}

}

*******************************************************************************************************
*** save the Acestry data set, which is the input for the analysis:

save "${path}/Data/original_data/cbos_with_1931.dta", replace
*******************************************************************************************************

